@@ -170,7 +170,7 @@ class SoapController(controllers.Controller):
         cherrypy.response.body = str(envelope)
     
     @tgexpose("genshi:tgwebservices.templates.soap",
-              content_type="text/xml", format="xml")
+              content_type="text/xml;charset=utf-8", format="xml")
     def index(self):
         """Processes SOAP requests and generates the responses."""
         # get request data and produce an ElementTree that we can work with.
@@ -193,7 +193,10 @@ class SoapController(controllers.Controller):
         params = {}
         for paramelem in body.getchildren():
             paramname = namespace_expr.sub("", paramelem.tag)
-            params[paramname] = paramelem.text
+            val = paramelem.text
+            if val is None:
+                val = ""
+            params[paramname] = val
         
         try:
             method = self.wscontroller._ws_funcs[methodname]
@@ -219,7 +222,7 @@ class SoapController(controllers.Controller):
         return data
     
     @tgexpose("genshi:tgwebservices.templates.wsdl", format="xml",
-              content_type="text/xml")
+              content_type="text/xml;charset=utf-8")
     def api_wsdl(self, xmlsoap=False):
         """Produces the WSDL for this SOAP service."""
         if self.arrays is None:
