@@ -1,6 +1,7 @@
 import cherrypy
 from turbogears import testutil
 
+from tgwebservices.controllers import WebServicesRoot, wsexpose, wsvalidate
 from tgwebservices.tests.fixtures import *
 
 def test_simple():
@@ -36,4 +37,30 @@ def test_error_handling():
     testutil.create_request("/somestrings?foo=1&tg_format=json")
     output = cherrypy.response.body[0]
     print output
-    assert output == """{"faultcode": "Client", "faultstring": "Unexpected parameter in function call (somestrings() got an unexpected keyword argument 'foo')"}"""
\ No newline at end of file
+    assert output == """{"faultcode": "Client", "faultstring": "Unexpected parameter in function call (somestrings() got an unexpected keyword argument 'foo')"}"""
+
+class BooleanInput(WebServicesRoot):
+    @wsexpose(bool)
+    @wsvalidate(bool)
+    def gotbool(self, truefalse):
+        return truefalse
+
+def test_boolean_input():
+    def check(test, expected):
+        cherrypy.root = BooleanInput("http://foo.bar.baz/")
+        testutil.create_request("/gotbool?tg_format=json&truefalse=%s" % test)
+        output = cherrypy.response.body[0]
+        print output
+        assert output == """{"result": %s}""" % expected
+    
+    tests = [
+        ("False", "false"),
+        ("True", "true"),
+        ("1", "true"),
+        ("0", "false"),
+        ("false", "false"),
+        ("no", "false")
+    ]
+    for test in tests:
+        yield check, test[0], test[1]
+        
\ No newline at end of file
