@@ -62,7 +62,7 @@ def test_wsdl_with_ints():
     testutil.create_request("/soap/api.wsdl")
     output = cherrypy.response.body[0]
     print output
-    assert cherrypy.response.headers["Content-Type"] == "text/xml"
+    assert cherrypy.response.headers["Content-Type"] == "text/xml;charset=utf-8"
     root = et.fromstring(output)
     schema_elements = root.findall(".//{http://www.w3.org/2001/XMLSchema}element")
     found = False
@@ -416,4 +416,18 @@ def test_optional():
             assert num2.attrib["minOccurs"] == "0"
             num3 = sequence.getchildren()[2]
             assert num3.attrib["name"] == "num3"
-            assert num3.attrib["minOccurs"] == "0"
\ No newline at end of file
+            assert num3.attrib["minOccurs"] == "0"
+
+class StringRoot(WebServicesRoot):
+    @wsexpose(str)
+    @wsvalidate(str)
+    def say_hello(self, name):
+        assert name is not None
+        assert name != "None"
+        return "Hi, %s" % name
+
+def test_empty_parameter_is_empty_string():
+    cherrypy.root = StringRoot("http://foo.bar.baz/")
+    output = run_soap("say_hello", """<name></name>""")
+    print output
+    assert "fault" not in output
